# OIO-Exporter metrics
Here is a list of all metrics that `oio-exporter` will export along with the naming convention and common labels.
## Convention
Source: https://prometheus.io/docs/practices/naming/
Each metric name will follow the following rules:
- prefixed with the `openio_` namespace
- must have a single unit (i.e. do not mix `seconds` with `milliseconds`, or `seconds` with `bytes`)
- should use base units (e.g. `seconds`, `bytes`, `meters` - not `milliseconds`, `megabytes`, `kilometers`)
- should have a suffix describing the unit, in plural form. Note that an accumulating count has total as a suffix, in addition to the unit if applicable.
  - `openio_xxx_duration_seconds`
  - `openio_xxx__memory_usage_bytes`
  - `openio_xxx_requests_total` (for a unit-less accumulating count)
  - `openio_xxx_process_cpu_seconds_total` (for an accumulating count with unit)
  - `openio_build_info` (for a pseudo-metric that provides metadata about the running binary)

As a rule of thumb, either the sum() or the avg() over all dimensions of a given metric should be meaningful (though not necessarily useful). If it is not meaningful, split the data up into multiple metrics. For example, having the capacity of various queues in one metric is good, while mixing the capacity of a queue with the current number of elements in the queue is not.

## Common labels
Use labels to differentiate the characteristics of the thing that is being measured:
- `openio_xxx_requests_total` - differentiate request methods: `method="GET|PUT|DELETE"`
- `openio_xx_duration_seconds` - differentiate response code : `code="2xx|4xx|5xx"`

The following labels are set for all metrics:
| Label | Value |
| ----- | ------|
| host      | `$(hostname)` |
| namespace | `<OpenIO namespace>` |

The following label must be set the same way for each metrics which will use them:
| Label | Value | Description |
| ----- | ------| ----------- |
| service_type  | `meta0`, `meta1`, `meta2`, `oioswift`, ...   | The type of the service|
| service_addr  | `<ip>:<port>`                                | The concatenation of the listening IP and PORT of a service |
| service_ip    | `<ip>`                                       | The IP address on which the service listens |
| service_port  | `<port>`                                     | The port on which the service listens |
| service       | `<namespace>-<service_type>-<service_index>` | The ID of the service as defined in the inventory and in gridinit |
| method        | `GET`, `PUT`, ...                            | The request method of requests |
| code          | `2xx`, `4xx`, `5xx`, ...                     | The response code a service can return to a request. Use agregation when possible to limit the number of series |
| status        | `failed`, `ok`, `waiting`                    | The status of something |
| disk          | `sda`, `UUID=xxxxxxxx`, `LABEL=xxxxxx`       | A disk identifier |
| mountpoint    | `/mnt/foo/bar`                               | A path to a mountpoint |
| direction     | `in`, `out`, ...                             | In which direction the data is going |

The following labels should not be used:
- `dimension` as it is generaly used for everything, use `method`, `code` or `status` instead

## Metrics
see dedicated modules documentation:
- [`healthcheck` module](../healthcheck/README.md)
- [`log` module](../log/README.md)
- [`oiofs` module](../oiofs/README.md)
- [`openio` module](../openio/README.md)
- [`redis` module](../redis/README.md)
- [`s3rt` module](../s3rt/README.md)
- [`version` module](../version/README.md)
- [`memcached` module](../memcached/README.md)
- [`beanstalkd` module](../beanstalkd/README.md)
- [`zookeeper` module](../zookeeper/README.md)
